@@ -1,8 +1,10 @@
+from ocha_stratus import datasources as codab
 from ocha_stratus.azure_blob import (
     get_container_client,
     list_container_blobs,
     load_blob_data,
     load_csv_from_blob,
+    load_geoparquet_from_blob,
     load_parquet_from_blob,
     load_shp_from_blob,
     open_blob_cog,
@@ -22,6 +24,7 @@ __all__ = [
     "get_container_client",
     "list_container_blobs",
     "load_csv_from_blob",
+    "load_geoparquet_from_blob",
     "load_parquet_from_blob",
     "load_shp_from_blob",
     "open_blob_cog",
@@ -36,4 +39,6 @@ __all__ = [
     "postgres_upsert",
     # Cogs
     "stack_cogs",
+    # Datasources
+    "codab",
 ]
